@@ -5,16 +5,15 @@
  */
 
 #include "LocalFilePKResource.h"
+#include "libdiscover_backend_debug.h"
+#include <PackageKit/Daemon>
+#include <PackageKit/Details>
 #include <QDebug>
 #include <QFileInfo>
 #include <QProcess>
-#include <PackageKit/Daemon>
-#include <PackageKit/Details>
 #include <utils.h>
-#include "config-paths.h"
-#include "libdiscover_backend_debug.h"
 
-LocalFilePKResource::LocalFilePKResource(QUrl path, PackageKitBackend* parent)
+LocalFilePKResource::LocalFilePKResource(QUrl path, PackageKitBackend *parent)
     : PackageKitResource(path.toString(), path.toString(), parent)
     , m_path(std::move(path))
 {
@@ -52,16 +51,18 @@ void LocalFilePKResource::fetchDetails()
 {
     if (!m_details.isEmpty())
         return;
-    m_details.insert(QStringLiteral("fetching"), true);//we add an entry so it's not re-fetched.
+    m_details.insert(QStringLiteral("fetching"), true); // we add an entry so it's not re-fetched.
 
-    PackageKit::Transaction* transaction = PackageKit::Daemon::getDetailsLocal(m_path.toLocalFile());
+    PackageKit::Transaction *transaction = PackageKit::Daemon::getDetailsLocal(m_path.toLocalFile());
     connect(transaction, &PackageKit::Transaction::details, this, &LocalFilePKResource::setDetails);
     connect(transaction, &PackageKit::Transaction::errorCode, this, &PackageKitResource::failedFetchingDetails);
 
-    PackageKit::Transaction* transaction2 = PackageKit::Daemon::getFilesLocal(m_path.toLocalFile());
+    PackageKit::Transaction *transaction2 = PackageKit::Daemon::getFilesLocal(m_path.toLocalFile());
     connect(transaction2, &PackageKit::Transaction::errorCode, this, &PackageKitResource::failedFetchingDetails);
-    connect(transaction2, &PackageKit::Transaction::files, this, [this] (const QString &/*pkgid*/, const QStringList & files) {
-        const auto execIdx = kIndexOf(files, [](const QString& file) { return file.endsWith(QLatin1String(".desktop")) && file.contains(QLatin1String("usr/share/applications")); });
+    connect(transaction2, &PackageKit::Transaction::files, this, [this](const QString & /*pkgid*/, const QStringList &files) {
+        const auto execIdx = kIndexOf(files, [](const QString &file) {
+            return file.endsWith(QLatin1String(".desktop")) && file.contains(QLatin1String("usr/share/applications"));
+        });
         if (execIdx >= 0) {
             m_exec = files[execIdx];
 
@@ -73,10 +74,12 @@ void LocalFilePKResource::fetchDetails()
             qWarning() << "could not find an executable desktop file for" << m_path << "among" << files;
         }
     });
-    connect(transaction2, &PackageKit::Transaction::finished, this, [] {qCDebug(LIBDISCOVER_BACKEND_LOG) << "."; });
+    connect(transaction2, &PackageKit::Transaction::finished, this, [] {
+        qCDebug(LIBDISCOVER_BACKEND_LOG) << ".";
+    });
 }
 
-void LocalFilePKResource::setDetails(const PackageKit::Details& details)
+void LocalFilePKResource::setDetails(const PackageKit::Details &details)
 {
     addPackageId(PackageKit::Transaction::InfoAvailable, details.packageId(), true);
     PackageKitResource::setDetails(details);
@@ -84,5 +87,5 @@ void LocalFilePKResource::setDetails(const PackageKit::Details& details)
 
 void LocalFilePKResource::invokeApplication() const
 {
-    QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {m_exec});
+    runService({m_exec});
 }
